@@ -1,3 +1,3 @@
 from holour.json_handler import json_encode, json_decode
-from holour.logging import setup_log, get_format
+from holour.logging import setup_log, get_format, get_json_format, json_log_handler
 from holour.config import load_configuration
