@@ -40,6 +40,10 @@ class JsonEncoder(json.JSONEncoder):
             return obj.__dict__
         elif isinstance(obj, AxisAngle):
             return obj.__dict__
+        elif isinstance(obj, Quaternion):
+            return obj.__dict__
+        elif isinstance(obj, PoseQuad):
+            return obj.__dict__
         else:
             return json.JSONEncoder.default(self, obj)
 
@@ -86,6 +90,10 @@ class JsonDecoder(json.JSONDecoder):
                 return RobotStateChange(**obj)
             if '_type' in obj and obj['_type'] == 'axis_angle':
                 return AxisAngle(**obj)
+            if '_type' in obj and obj['_type'] == 'quad':
+                return Quaternion(**obj)
+            if '_type' in obj and obj['_type'] == 'pose_quad':
+                return PoseQuad(**obj)
         return obj
 
 
