@@ -8,7 +8,8 @@ class Test(TestCase):
 
     def test_task(self):
 
-        task = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)), [Task.ASSIGNED_TO_HUMAN])
+        task = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)),
+                    [Task.ASSIGNED_TO_HUMAN], Task.ASSIGNED_TO_HUMAN)
         task_string = json_encode(task)
         expected_string = '{"_type": "task", "uuid": "uuid", "name": "name", "product_uuid": "product_uuid", ' \
                           '"pose": {"_type": "pose", "name": "", "position": {"_type": "vector3", "x": 0.0, ' \
@@ -25,9 +26,12 @@ class Test(TestCase):
         assert task_decoded == task, "The decoded object must be equal to the encoded"
 
     def test_task_equals(self):
-        task1 = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)), [Task.ASSIGNED_TO_HUMAN])
-        task2 = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)), [Task.ASSIGNED_TO_HUMAN])
-        task3 = Task('other', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)), [Task.ASSIGNED_TO_HUMAN])
+        task1 = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)),
+                     [Task.ASSIGNED_TO_HUMAN], Task.ASSIGNED_TO_HUMAN)
+        task2 = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)),
+                     [Task.ASSIGNED_TO_HUMAN], Task.ASSIGNED_TO_HUMAN)
+        task3 = Task('other', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)),
+                     [Task.ASSIGNED_TO_HUMAN], Task.ASSIGNED_TO_HUMAN)
 
         assert task1 == task2
         assert task1 != task3
@@ -35,7 +39,7 @@ class Test(TestCase):
 
     def test_task_repr(self):
         task = Task('uuid', 'name', 'product_uuid', Pose(Vector3(0.0, 0.0, 0.0), Vector3(0.0, 0.0, 0.0)),
-                    [Task.ASSIGNED_TO_HUMAN], description="Hard task!")
+                    [Task.ASSIGNED_TO_HUMAN], Task.ASSIGNED_TO_HUMAN, description="Hard task!")
         expected, got = 'Hard task!', f'{task}'
 
         assert expected in got, f"Expected {expected} in got: {got}"
